@@ -19,4 +19,8 @@ fn find_libarchive() {
     vcpkg::Config::new()
         .find_package("libarchive")
         .expect("Unable to find libarchive");
+
+    println!("cargo:rustc-link-lib=static=archive");
+    println!("cargo:rustc-link-lib=User32");
+    println!("cargo:rustc-link-lib=Crypt32");
 }
